class InvalidHashException(Exception):
    pass


class InvalidIPException(Exception):
    pass


class NoConfiguredServicesException(Exception):
    pass


class InvalidCredentialsException(Exception):
    pass
